@@ -505,10 +505,10 @@ access_config (access_type mode, const char *section_name,
 	return def;
 }
 
-/* an extended version of access_config for looking up values in ~/.gnome.
+/* an extended version of access_config for looking up values in ~/.gnome2.
  * For writes it falls through to the standard behaviour.
  * For lookups, it first checks for the value in
- * $(datadir)/gnome/config-override, and if it isn't there in ~/.gnome,
+ * $(datadir)/gnome/config-override, and if it isn't there in ~/.gnome2,
  * then checks $(datadir)/gnome/config, and as a last fallback uses def.
  * This gives system administrators high level control over the default
  * configuration values for GNOME
@@ -656,10 +656,9 @@ static gint
 check_path(char *path, mode_t newmode)
 {
 	gchar *dirpath;
-	gchar *p;
+	gchar *p, *cur;
 	GString *newpath;
 	struct stat s;
-	char *tokp;
 
 	g_return_val_if_fail (path != NULL, FALSE);
 
@@ -695,9 +694,15 @@ check_path(char *path, mode_t newmode)
 	while(*p == '/')
 		p++;
 
-	p = strtok_r(p, "/", &tokp);
+	cur = p;
 	newpath = g_string_new("");
-	do {
+	while ((p = cur)) {
+	       	cur = strchr (cur, '/');
+		if (cur) {
+			*cur = '\0';
+			cur++;
+		}
+		
 		newpath = g_string_append_c(newpath,'/');
 		newpath = g_string_append(newpath,p);
 		if(stat(newpath->str,&s)==0) {
@@ -715,8 +720,7 @@ check_path(char *path, mode_t newmode)
 				return FALSE;
 			}
 		}
-
-	} while ((p = strtok_r(NULL, "/", &tokp)) != NULL);
+	}
 
 	g_string_free(newpath,TRUE);
 
@@ -1348,7 +1352,9 @@ gnome_config_drop_all (void)
  * gnome_config_get_int:
  * @path: A gnome configuration path to an item.
  *
- * Returns: The value of a configuration item as an integer.
+ * Retrieves an integer value configuration item.
+ *
+ * Returns: The value of a configuration item.
  */
 /**
  * gnome_config_private_get_int:
@@ -1365,6 +1371,8 @@ gnome_config_drop_all (void)
  * @def: A pointer to a flag that will be set if the default value for the item
  * is returned.
  *
+ * Retrieves an integer value configuration item.
+ *
  * Returns: The value of a configuration item as an integer or @def if the
  * configuration item does not exist.
  */
@@ -1411,8 +1419,9 @@ gnome_config_get_int_with_default_ (const char *path, gboolean *def, gboolean pr
  * gnome_config_get_float:
  * @path: A gnome configuration path to an item.
  *
- * Returns: The value of a configuration item as a floating-point
- * number.
+ * Retrieves a floating-point valued configuration item.
+ *
+ * Returns: The value of a configuration item.
  */
 /**
  * gnome_config_private_get_float:
@@ -1430,6 +1439,8 @@ gnome_config_get_int_with_default_ (const char *path, gboolean *def, gboolean pr
  * @def: A pointer to a flag that will be set if the default value for the item
  * is returned.
  *
+ * Retrieves a floating-point valued configuration item.
+ *
  * Returns: The value of a configuration item as a floating-point
  * number or @def if the configuration item does not exist.
  */
@@ -1693,7 +1704,9 @@ gnome_config_get_string_with_default_ (const char *path, gboolean *def,
  * gnome_config_get_bool:
  * @path: A gnome configuration path to an item.
  *
- * Returns: The value of a configuration item as a boolean.
+ * Retrieves a boolean configuration value.
+ *
+ * Returns: The value of a configuration item.
  */
 /**
  * gnome_config_private_get_bool:
@@ -1709,7 +1722,9 @@ gnome_config_get_string_with_default_ (const char *path, gboolean *def,
  * @def: A pointer to a flag that will be set if the default value for the item
  * is returned.
  *
- * Returns: The value of a configuration item as a boolean, or @def if the
+ * Retrieves a boolean configuration value.
+ *
+ * Returns: The value of a configuration item, or @def if the
  * configuration item does not exist.
  */
 /**
